@@ -7,11 +7,11 @@ __all__ = [
     "GeneralManagerMeta",
     "GroupManager",
     "Input",
-    "graphQlProperty",
+    "graph_ql_property",
 ]
 
-from general_manager.manager.generalManager import GeneralManager
+from general_manager.manager.general_manager import GeneralManager
 from general_manager.manager.meta import GeneralManagerMeta
-from general_manager.manager.groupManager import GroupManager
+from general_manager.manager.group_manager import GroupManager
 from general_manager.manager.input import Input
-from general_manager.api.property import graphQlProperty
+from general_manager.api.property import graph_ql_property
